#include "iostream"
#include "svg.h"

const auto IMAGE_WIDTH = 400;
const auto IMAGE_HEIGHT = 300;
const auto TEXT_LEFT = 20;
const auto TEXT_BASELINE = 20;
const auto TEXT_WIDTH = 50;
const auto BIN_HEIGHT = 30;

void svg_begin(double width, double height, std::vector <double>& test)
{
    test.push_back(width);
    test.push_back(height);
    std::cout << "<?xml version='1.0' encoding='UTF-8'?>\n";
    std::cout << "<svg ";
    std::cout << "width='" << width << "' ";
    std::cout << "height='" << height << "' ";
    std::cout << "viewBox='0 0 " << width << " " << height << "' ";
    std::cout << "xmlns='http://www.w3.org/2000/svg'>\n";
}

void svg_text(double left, double baseline, std::string text)
{
    std::cout << "<text x='"<< left <<"' y='"<< baseline <<"'>"<< text <<"</text>";
}

void svg_rect(double x, double y, double width, double height, std::string stroke = "black", std::string fill = "red")
{
    std::cout<< "<rect x='"<< x <<"' y='"<< y <<"' width='"<< width <<"' height='"<< height<<"' stroke='black' fill='red' ></rect>";
}

void svg_line(double x, double y, double x2, double y2, std::vector <double>& test)
{
    test.push_back(x);
    test.push_back(y);
    test.push_back(x2);
    test.push_back(y2);
    std::cout<<"<line x1='"<< x <<"' y1='"<< y <<"' x2='"<< x2 <<"' y2='"<< y2 <<"' stroke-dasharray = '10 10' stroke='black';stroke-width:4' />";
}



void
show_histogram_svg(const std::vector<size_t>& bins, size_t & max_count, size_t & bin_count, std::vector <double>& test)
{

    const auto BLOCK_WIDTH = (IMAGE_WIDTH - TEXT_WIDTH)/max_count;
    svg_begin(IMAGE_WIDTH+4, IMAGE_HEIGHT, test);
    double top = 4;

    svg_line(TEXT_LEFT, top, IMAGE_WIDTH+5, top, test);
    svg_line(TEXT_LEFT-10, top, TEXT_LEFT-10, top+3*BIN_HEIGHT, test);
    svg_line(IMAGE_WIDTH+5, top, IMAGE_WIDTH+5, 2*top+3*BIN_HEIGHT, test);
    svg_line(TEXT_LEFT, 2*top+3*BIN_HEIGHT, IMAGE_WIDTH+5, 2*top+3*BIN_HEIGHT, test);
    for (double t : test)
    {
        std:: cout << t<< '\n';
    }
    for (size_t bin : bins)
    {
        const double bin_width = BLOCK_WIDTH * bin;
        svg_text(TEXT_LEFT, top + TEXT_BASELINE, std::to_string(bin));
        svg_rect(TEXT_WIDTH+2, top+2, bin_width, BIN_HEIGHT);
        top += BIN_HEIGHT;
    }
    svg_end();
}




void
svg_end()
{
    std::cout << "</svg>\n";
}
